summaryrefslogtreecommitdiff
path: root/source4/scripting
diff options
context:
space:
mode:
authorAndrew Bartlett <abartlet@samba.org>2012-06-16 13:06:44 +1000
committerAndrew Bartlett <abartlet@samba.org>2012-06-16 08:18:10 +0200
commitd9f7195a1f5a12d5dc8865aa5553b61a4f770e3d (patch)
tree2ab5ec9cf03d2d31eb05219434cd30a893b8d5d2 /source4/scripting
parent39766b75a40fbab73fc23dd947de44f8349ed466 (diff)
downloadsamba-d9f7195a1f5a12d5dc8865aa5553b61a4f770e3d.tar.gz
samba-d9f7195a1f5a12d5dc8865aa5553b61a4f770e3d.tar.bz2
samba-d9f7195a1f5a12d5dc8865aa5553b61a4f770e3d.zip
s4-classicupgrade: Use "samba classic" description for samba3 NT4-like domains in samba3upgrade
Diffstat (limited to 'source4/scripting')
-rw-r--r--source4/scripting/python/samba/netcmd/domain.py17
1 files changed, 9 insertions, 8 deletions
diff --git a/source4/scripting/python/samba/netcmd/domain.py b/source4/scripting/python/samba/netcmd/domain.py
index 02b30c35b3..a5d5e473c9 100644
--- a/source4/scripting/python/samba/netcmd/domain.py
+++ b/source4/scripting/python/samba/netcmd/domain.py
@@ -814,14 +814,14 @@ class cmd_domain_passwordsettings(Command):
raise CommandError("Wrong argument '%s'!" % subcommand)
-class cmd_domain_samba3upgrade(Command):
- """Upgrade from Samba3 database to Samba4 AD database.
+class cmd_domain_classicupgrade(Command):
+ """Upgrade from Samba classic (NT4-like) database to Samba AD DC database.
- Specify either a directory with all samba3 databases and state files (with --dbdir) or
- samba3 testparm utility (with --testparm).
+ Specify either a directory with all Samba classic DC databases and state files (with --dbdir) or
+ the testparm utility from your classic installation (with --testparm).
"""
- synopsis = "%prog [options] <samba3_smb_conf>"
+ synopsis = "%prog [options] <classic_smb_conf>"
takes_optiongroups = {
"sambaopts": options.SambaOptions,
@@ -830,9 +830,9 @@ class cmd_domain_samba3upgrade(Command):
takes_options = [
Option("--dbdir", type="string", metavar="DIR",
- help="Path to samba3 database directory"),
+ help="Path to samba classic DC database directory"),
Option("--testparm", type="string", metavar="PATH",
- help="Path to samba3 testparm utility from the previous installation. This allows the default paths of the previous installation to be followed"),
+ help="Path to samba classic DC testparm utility from the previous installation. This allows the default paths of the previous installation to be followed"),
Option("--targetdir", type="string", metavar="DIR",
help="Path prefix where the new Samba 4.0 AD domain should be initialised"),
Option("--quiet", help="Be quiet", action="store_true"),
@@ -939,4 +939,5 @@ class cmd_domain(SuperCommand):
subcommands["join"] = cmd_domain_join()
subcommands["level"] = cmd_domain_level()
subcommands["passwordsettings"] = cmd_domain_passwordsettings()
- subcommands["samba3upgrade"] = cmd_domain_samba3upgrade()
+ subcommands["classicupgrade"] = cmd_domain_classicupgrade()
+ subcommands["samba3upgrade"] = cmd_domain_classicupgrade()